from .AnimeAvatar import AnimeAvatar
from .ArtAlbum import ArtAlbum
from .cosplay import CosPlay
from .CoupleAvatar import CoupleAvatar
from .FemaleAvatar import FemaleAvatar
from .Figure import Figure
from .hanfu import HanFu
from .jk import JK
from .lolita import Lolita
from .MaleAvatar import MaleAvatar
from .pcpic import PcPic
from .phonepic import PhonePic
from .SelectedIllustrations import SelectedIllustrations
from .SelectedPixiv import SelectedPixiv

__all__ = ['AnimeAvatar', 'ArtAlbum', 'CosPlay', 'CoupleAvatar', 'FemaleAvatar', 'Figure', 
            'HanFu', 'JK', 'Lolita', 'MaleAvatar', 'PcPic', 'PhonePic', 'SelectedIllustrations', 
            'SelectedPixiv']
__title__ = 'dimtown'
__description__ = 'A Spider for https://dimtown.com'
__url__ = 'https://github.com/Cvandia/dimtown-spider'
__version__ = '0.0.1'
__author__ = 'Cvandia'
__author_email__ = '1141538825@qq.com'
__license__ = 'MIT License'